@@ -1,3 +1,4 @@
+from .model_location import ModelLocation
 from .model_version import ModelVersion
 
 
@@ -6,7 +7,7 @@ class Model():
 
     '''
 
-    def __init__(self, client, name=None, modelId=None, modelConfig=None, createdAt=None, projectId=None, shared=None, sharedAt=None, refreshSchedules=None, location=None, latestModelVersion={}):
+    def __init__(self, client, name=None, modelId=None, modelConfig=None, createdAt=None, projectId=None, shared=None, sharedAt=None, refreshSchedules=None, location={}, latestModelVersion={}):
         self.client = client
         self.id = modelId
         self.name = name
@@ -17,7 +18,7 @@ class Model():
         self.shared = shared
         self.shared_at = sharedAt
         self.refresh_schedules = refreshSchedules
-        self.location = location
+        self.location = client._build_class(ModelLocation, location)
         self.latest_model_version = client._build_class(
             ModelVersion, latestModelVersion)
 
@@ -28,7 +29,7 @@ class Model():
         return self.__class__ == other.__class__ and self.id == other.id
 
     def to_dict(self):
-        return {'name': self.name, 'model_id': self.model_id, 'model_config': self.model_config, 'created_at': self.created_at, 'project_id': self.project_id, 'shared': self.shared, 'shared_at': self.shared_at, 'refresh_schedules': self.refresh_schedules, 'location': self.location, 'latest_model_version': self.latest_model_version.to_dict() if self.latest_model_version else None}
+        return {'name': self.name, 'model_id': self.model_id, 'model_config': self.model_config, 'created_at': self.created_at, 'project_id': self.project_id, 'shared': self.shared, 'shared_at': self.shared_at, 'refresh_schedules': self.refresh_schedules, 'location': [elem.to_dict() for elem in self.location or []], 'latest_model_version': [elem.to_dict() for elem in self.latest_model_version or []]}
 
     def refresh(self):
         self = self.describe()
@@ -55,8 +56,8 @@ class Model():
     def delete(self):
         return self.client.delete_model(self.model_id)
 
-    def create_deployment(self, name=None, description=None, calls_per_second=None):
-        return self.client.create_deployment(self.model_id, name, description, calls_per_second)
+    def create_deployment(self, name=None, description=None, calls_per_second=None, auto_deploy=True):
+        return self.client.create_deployment(self.model_id, name, description, calls_per_second, auto_deploy)
 
     def wait_for_training(self, timeout=None):
         return self.client._poll(self, {'PENDING', 'TRAINING'}, delay=30, timeout=timeout)
@@ -64,5 +65,10 @@ class Model():
     def wait_for_evaluation(self, timeout=None):
         return self.wait_for_training()
 
-    def get_status(self):
+    def wait_for_full_automl(self, timeout=None):
+        return self.client._poll(self, {'PENDING', 'TRAINING'}, delay=30, timeout=timeout, poll_args={'get_automl_status': True})
+
+    def get_status(self, get_automl_status: bool = False):
+        if get_automl_status:
+            return self.client._call_api('describeModel', 'GET', query_params={'modelId': self.model_id, 'waitForFullAutoml': True}, parse_type=Model).latest_model_version.status
         return self.describe().latest_model_version.status
